@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 from typing import List
 
-from polytope import shapes
+from polytope_feature import shapes
 
 
 class Feature(ABC):
@@ -21,6 +21,10 @@ class Feature(ABC):
     def coverage_type(self):
         pass
 
+    @abstractmethod
+    def parse(self, request, feature_config):
+        pass
+
     def validate(self, request):
         incompatible_keys = self.incompatible_keys()
         for key in incompatible_keys:
